@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::Action::DWIM;
 {
-  $App::Magpie::Action::DWIM::VERSION = '2.001';
+  $App::Magpie::Action::DWIM::VERSION = '2.002';
 }
 # ABSTRACT: dwim command implementation
 
@@ -53,7 +53,7 @@ sub run {
         my $pkg = ( $module->packages )[0];
         my $modname = $module->name;
         my $pkgname = $pkg->name;
-        return if $seen{$pkgname}++; # do not try to update a pkg more than once
+        next if $seen{$pkgname}++; # do not try to update a pkg more than once
 
         # forks and returns the pid for the child:
         my $pid = $pm->start($pkgname) and next;
@@ -90,7 +90,7 @@ App::Magpie::Action::DWIM - dwim command implementation
 
 =head1 VERSION
 
-version 2.001
+version 2.002
 
 =head1 SYNOPSIS
 
